@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/FontList.c,v 1.2 2004/09/27 16:54:10 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/FontList.c,v 1.7 2004/12/03 19:45:36 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 2000, 2001, 2002, 2004 LessTif Development Team
@@ -23,9 +23,12 @@
  *
  **/
 
-static const char rcsid[] = "$Id: FontList.c,v 1.2 2004/09/27 16:54:10 dannybackx Exp $";
+static const char rcsid[] = "$Id: FontList.c,v 1.7 2004/12/03 19:45:36 dannybackx Exp $";
 
 #include <LTconfig.h>
+
+#include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <locale.h>
 #include <XmI/XmI.h>
@@ -87,7 +90,7 @@ __XmFontListDealloc(XmFontList list)
 {
 	int	i;
 
-	DEBUGOUT(_LtDebug(__FILE__, NULL, "__XmFontListDealloc(%p) count %d\n",
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "__XmFontListDealloc(%p), %d entries\n",
 				list, list->count));
 
 	if (list) {
@@ -193,7 +196,10 @@ XmFontListAppendEntry(XmFontList old, XmFontListEntry entry)
 				old, entry, old->renditions[i], i, old->renditions[i]->count));
 		}
 
+#if 1
+		/* HUH DANNY HACK DANNY FIX ME FIXME */
 		__XmFontListDealloc(old);
+#endif
 	}
 
 	/* Additionally allocate the structure here !! */
@@ -346,6 +352,14 @@ extern XmFontList XmFontListCopy(XmFontList fontlist)
 	XmFontList newFontList;
 	int i;
 
+#ifdef DEBUG_POINTERS
+	if (fontlist->count > 10) {
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListCopy(%p) count %d !!\n",
+					fontlist, fontlist->count));
+	} else {
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListCopy(%p)\n", fontlist));
+	}
+#endif
 	if (!fontlist) {
 		return (XmFontList)NULL;
 	}
@@ -409,7 +423,6 @@ XmFontListEntryFree(XmFontListEntry *pentry)
 #ifdef DEBUG_POINTERS
 	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryFree(%p) free !\n", e));
 #endif
-	XtFree(e->tag);
 
 #ifdef	USE_XFT
 	if (e->dpy) {
@@ -426,9 +439,8 @@ XmFontListEntryFree(XmFontListEntry *pentry)
 	}
 #endif
 
-#if (XmVERSION > 1)
+	XtFree(e->tag);
 	XtFree(e->font_name);
-#endif
 	XtFree((char *)e);
 }
 
@@ -467,109 +479,103 @@ XmFontListEntryGetTag(XmFontListEntry entry)
     return XtNewString(entry->tag);
 }
 
-
 extern XmFontListEntry
-XmFontListEntryLoad(Display *display,
-		    char *font_name,
-		    XmFontType type,
-		    char *tag)
+XmFontListEntryLoad(Display *display, char *font_name, XmFontType type, char *tag)
 {
-    XmFontListEntry entry;
-    XrmValue fromString, toFont, cvtArg[2];
-    Boolean success = False;
-    char *p, *locale;
+	XmFontListEntry	entry;
+	XrmValue	fromString, toFont, cvtArg[2];
+	Boolean		success = False;
+	char		*p, *locale;
+	XtCacheRef	cacherefs[2];
 
-    DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryLoad(%s, tag %s)\n",
-		      font_name, tag));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryLoad(%s, tag %s)\n",
+		font_name, tag));
 
-    /* Strip trailing semi-colon */
-    for (p = font_name; *p; p++)
-    {
-    }
+	/* Strip trailing semi-colon */
+	for (p = font_name; *p; p++) {
+	}
 
-    while (p > font_name && *(p - 1) == ',')
-    {
-	p--;
-	*p = '\0';
-    }
+	while (p > font_name && *(p - 1) == ',') {
+		p--;
+		*p = '\0';
+	}
 
-    if (*font_name == '"' && *(p-1) == '"') {
-	font_name++;
-	p--;
-	*p = '\0';
-    }
+	if (*font_name == '"' && *(p-1) == '"') {
+		font_name++;
+		p--;
+		*p = '\0';
+	}
 
-    fromString.addr = font_name;
-    fromString.size = strlen(font_name) + 1;
+	fromString.addr = font_name;
+	fromString.size = strlen(font_name) + 1;
 
-    cvtArg[0].addr = (XPointer)&display;
-    cvtArg[0].size = sizeof(Display *);
+	cvtArg[0].addr = (XPointer)&display;
+	cvtArg[0].size = sizeof(Display *);
 
-    entry = (XmFontListEntry)XtMalloc(sizeof(struct __XmRenditionRec));
-    memset(entry, 0, sizeof(struct __XmRenditionRec));
-    entry->font = NULL; /* for the XtCallConverter() call */
-    entry->count = 1;
-#if (XmVERSION > 1)
-    entry->dpy = display;
-    entry->rendition_foreground = XmAS_IS;
-    entry->rendition_background = XmAS_IS;
-#endif
+	entry = (XmFontListEntry)XtMalloc(sizeof(struct __XmRenditionRec));
+	memset(entry, 0, sizeof(struct __XmRenditionRec));
+	entry->font = NULL; /* for the XtCallConverter() call */
+	entry->count = 1;
+	entry->dpy = display;
+	entry->rendition_foreground = XmAS_IS;
+	entry->rendition_background = XmAS_IS;
 #ifdef	USE_XFT
 	/* Nothing to do, already cleared by memset() */
 #endif
 
-    switch (type)
-    {
-    case XmFONT_IS_FONT:
-	toFont.addr = (XPointer)&(entry->font);
-	toFont.size = sizeof(XFontStruct *);
+	switch (type) {
+	case XmFONT_IS_FONT:
+		toFont.addr = (XPointer)&(entry->font);
+		toFont.size = sizeof(XFontStruct *);
 
-	success = XtCallConverter(display, XtCvtStringToFontStruct, cvtArg,
-	                          (Cardinal)1, &fromString, &toFont, NULL);
-	break;
+#if 0
+		fprintf(stderr, "XtCallConverter(XtCvtStringToFontStruct)\n");
+#endif
+		success = XtCallConverter(display, XtCvtStringToFontStruct, cvtArg,
+			(Cardinal)1, &fromString, &toFont, cacherefs);
+		break;
 
-    case XmFONT_IS_FONTSET:
-	toFont.addr = (XPointer)&(entry->font);
-	toFont.size = sizeof(XFontSet);
+	case XmFONT_IS_FONTSET:
+		toFont.addr = (XPointer)&(entry->font);
+		toFont.size = sizeof(XFontSet);
 
-	/* XtCvtStringToFontSet needs 2 arguments : display and locale */
-	locale = setlocale(LC_CTYPE, NULL);
-	setlocale(LC_CTYPE, locale);
-	cvtArg[1].addr = (XPointer)XtNewString(locale);
-	cvtArg[1].size = sizeof(char *);
+		/* XtCvtStringToFontSet needs 2 arguments : display and locale */
+		locale = setlocale(LC_CTYPE, NULL);
+		setlocale(LC_CTYPE, locale);
+		cvtArg[1].addr = (XPointer)XtNewString(locale);
+		cvtArg[1].size = sizeof(char *);
 
-	success = XtCallConverter(display, XtCvtStringToFontSet, cvtArg,
-	                          (Cardinal)2, &fromString, &toFont, NULL);
-	XtFree(cvtArg[1].addr);
-	break;
-    case XmFONT_IS_XFT:
+#if 0
+		fprintf(stderr, "XtCallConverter(XtCvtStringToFontSet)\n");
+#endif
+		success = XtCallConverter(display, XtCvtStringToFontSet, cvtArg,
+			(Cardinal)2, &fromString, &toFont, cacherefs);
+		XtFree(cvtArg[1].addr);
+		break;
+	case XmFONT_IS_XFT:
 #ifdef	USE_XFT
 #endif
-	break;
-    case XmFONT_IS_XOC:
+		break;
+	case XmFONT_IS_XOC:
 #ifdef	USE_BIDI
 #endif
-	break;
-    }
+		break;
+	}
 
-    if (!success || !entry->font)
-    {
-	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryLoad => NULL\n"));
-	XtFree((char *)entry);
-	return (XmFontListEntry)NULL;
-    }
-    else
-    {
-	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryLoad success!  fle %p fs %p fid %p\n",
-		entry, entry->font, ((XFontStruct *)(entry->font))->fid));
-	entry->tag = XtNewString(tag);
-	entry->type = type;
-#if (XmVERSION > 1)
-	entry->font_name = XtNewString(font_name);
-#endif
+	if (!success || !entry->font) {
+		DEBUGOUT(_LtDebug(__FILE__, NULL, "XmFontListEntryLoad => NULL\n"));
+		XtFree((char *)entry);
+		return (XmFontListEntry)NULL;
+	} else {
+		DEBUGOUT(_LtDebug(__FILE__, NULL,
+			"XmFontListEntryLoad success!  fle %p fs %p fid %p\n",
+			entry, entry->font, ((XFontStruct *)(entry->font))->fid));
+		entry->tag = XtNewString(tag);
+		entry->type = type;
+		entry->font_name = XtNewString(font_name);
 
-	return entry;
-    }
+		return entry;
+	}
 }
 
 extern void
@@ -718,11 +724,13 @@ XmFontListRemoveEntry(XmFontList oldlist,
     if (oldnr==newnr)
     {
        __XmFontListDealloc(newFontList);
+       newFontList = 0;
        return oldlist;
      }
     else
     {
        __XmFontListDealloc(oldlist);
+       oldlist = 0;
        return newFontList;
      }
 }
