@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.7 2004/10/27 19:31:15 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.8 2005/03/22 14:48:03 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.7 2004/10/27 19:31:15 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Label.c,v 1.8 2005/03/22 14:48:03 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -148,7 +148,6 @@ static XtResource resources[] =
 	sizeof(Dimension), Offset(margin_bottom),
 	XmRImmediate, (XtPointer)0
     },
-#if (XmVERSION > 1)
     {
 	/*
 	 * Note !!
@@ -160,8 +159,6 @@ static XtResource resources[] =
 	sizeof(Boolean), Offset(check_set_render_table),
 	XmRImmediate, (XtPointer)NULL
     },
-#endif
-#if (XmVERSION > 1)
     {
 	XmNfontList, XmCFontList, XmRFontList,
 	sizeof(XmFontList), Offset(font),
@@ -172,13 +169,7 @@ static XtResource resources[] =
 	sizeof(XmFontList), Offset(font),
 	XmRCallProc, (XtPointer)_XmLabelSetRenderTable
     },
-#else
-    {
-	XmNfontList, XmCFontList, XmRFontList,
-	sizeof(XmFontList), Offset(font),
-	XmRImmediate, (XtPointer)NULL
-    },
-#endif
+    /* End of fontList and renderTable resources */
     {
 	XmNlabelPixmap, XmCLabelPixmap, XmRPrimForegroundPixmap,
 	sizeof(Pixmap), Offset(pixmap),
@@ -1902,7 +1893,6 @@ _XmLabelSetRenderTable(Widget w, int o, XrmValue *v)
 {
 	XmLabelWidget	lw = (XmLabelWidget)w;
 
-#if (XmVERSION > 1)
 	DEBUGOUT(_LtDebug(__FILE__, w, "_XmLabelSetRenderTable (%d)\n",
 		lw->label.check_set_render_table));
 	if (lw->label.check_set_render_table) {
@@ -1911,21 +1901,10 @@ _XmLabelSetRenderTable(Widget w, int o, XrmValue *v)
 		 * Therefore the result is undefined.
 		 */
 		v->addr = NULL;	/* FIX ME or should we pass nothing ? */
-#if 0
-	/* Don't generate a warning here, not even in LESSTIF_VERBOSE.
-	 * - this is really too much */
-		_XmWarning(w, "Shouldn't set both XmNfontList and XmNrenderTable\n");
-#endif
 	} else {
 		v->addr = (char *)&(lw->label.font);
 		lw->label.check_set_render_table = True;
 		DEBUGOUT(_LtDebug(__FILE__, w, "_XmLabelSetRenderTable rt %p\n",
 			lw->label.font));
 	}
-#else
-	/* Motif 1.x */
-	v->addr = (char *)&(lw->label.font);
-	DEBUGOUT(_LtDebug(__FILE__, w, "_XmLabelSetRenderTable [Motif 1.x] %p\n",
-		Lab_Font(lw)));
-#endif
 }
