@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manager.c,v 1.3 2004/09/28 18:39:08 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manager.c,v 1.4 2004/10/21 18:54:00 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manager.c,v 1.3 2004/09/28 18:39:08 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manager.c,v 1.4 2004/10/21 18:54:00 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -54,7 +54,6 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manage
 #include <Xm/RowColumnP.h>
 #include <Xm/DialogS.h>
 
-#if XmVERSION > 1
 #include <XmI/ManagerI.h>
 /* 
  * Traits  
@@ -63,12 +62,9 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/Manage
 #include <Xm/LayoutT.h>
 #include <XmI/DirectionI.h>
 #include <Xm/CareVisualT.h>
-#endif
 
 #include <XmI/DebugUtil.h>
 
-
-#if XmVERSION > 1
 static XmDirection get_direction(Widget w);
 
 static XmSpecifyLayoutDirectionTraitRec _XmManagerLayoutTraitRec =
@@ -76,7 +72,6 @@ static XmSpecifyLayoutDirectionTraitRec _XmManagerLayoutTraitRec =
     0,				/* version */
     get_direction		/* getValue */
 };
-#endif
 
 
 /* Forward Declarations */
@@ -90,14 +85,6 @@ static void destroy(Widget w);
 static Boolean set_values(Widget current, Widget request, Widget new_w,
 			  ArgList args, Cardinal *num_args);
 
-/*
-   static XtGeometryResult geometry_manager(Widget w,
-   XtWidgetGeometry *request,
-   XtWidgetGeometry *reply);
-
-   static void changed_managed(Widget w);
- */
-
 static void constraint_initialize(Widget request, Widget new_w,
 				  ArgList args, Cardinal *num_args);
 static XmNavigability widget_navigable(Widget w);
@@ -307,8 +294,6 @@ static XtResource resources[] =
 	sizeof(Widget), Offset(initial_focus),
 	XmRImmediate, (XtPointer)NULL
     }
-
-#if XmVERSION > 1
     ,
     {
 	XmNpopupHandlerCallback, XmCCallback, XmRCallback,
@@ -321,7 +306,6 @@ static XtResource resources[] =
 	sizeof(XmDirection), Offset(string_direction),
 	XmRImmediate, (XtPointer)((XmDirection) NULL)	/* dynamic how? */
     }
-#endif
 };
 
 #define MOffset(field)	XtOffset(XmManagerWidget, manager.field)
@@ -361,13 +345,11 @@ static XmSyntheticResource syn_resources[] =
 	sizeof(Dimension), MOffset(shadow_thickness),
 	_XmFromHorizontalPixels, _XmToHorizontalPixels
     },
-#if XmVERSION > 1
     {
 	XmNstringDirection,
 	sizeof(XmStringDirection), MOffset(string_direction),
 	_XmFromLayoutDirection, _XmToLayoutDirection
     },
-#endif
 };
 
 static XmBaseClassExtRec _XmManagerCoreClassExtRec = {
@@ -454,8 +436,8 @@ XmManagerClassRec xmManagerClassRec = {
     },
     /* Composite class part */
     {
-	/* geometry manager */ NULL /*geometry_manager*/,
-        /* change_managed   */ NULL /*changed_managed*/,
+	/* geometry manager */ NULL,
+        /* change_managed   */ NULL,
         /* insert_child     */ XtInheritInsertChild,
         /* delete_child     */ XtInheritDeleteChild,
         /* extension        */ (XtPointer)&managerCompositeExt,
@@ -604,7 +586,6 @@ class_part_initialize(WidgetClass widget_class)
 			  msc->manager_class.num_syn_constraint_resources);
     }
 
-#if XmVERSION > 1
     /* FIX ME: do I need to worry about subclasses */
     /* initialize traits */
     if (!XmeTraitSet((XtPointer)xmManagerWidgetClass, XmQTspecifyLayoutDirection,
@@ -612,7 +593,6 @@ class_part_initialize(WidgetClass widget_class)
     {
 	_XmWarning(NULL, "XmManager ClassInitialize: XmeTraitSet failed\n");
     }
-#endif
 }
 
 static void
@@ -894,37 +874,14 @@ realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 }
 
 static Boolean
-set_values(Widget old,
-	   Widget request,
-	   Widget new_w,
-	   ArgList args,
-	   Cardinal *num_args)
+set_values(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num_args)
 {
 	Boolean need_refresh = False;
-#if	XmVERSION > 1
 	/* A variable to hold the trait flags */
 	Mask	msk = 0;
-#endif
 
     DEBUGOUT(_LtDebug(__FILE__, new_w, "SetValues()\n"));
 
-#if 0
-    if (XtWidth(new_w) != XtWidth(old) && XtWidth(new_w) == 0)
-    {
-	_XmWarning(new_w,
-	 "XmManager SetValues: won't set width of widget to 0 (previous %d)\n",
-		   XtWidth(old));
-	XtWidth(new_w) = XtWidth(old);
-    }
-    if (XtHeight(new_w) != XtHeight(old) && XtHeight(new_w) == 0)
-    {
-	_XmWarning(new_w,
-	"XmManager SetValues: won't set height of widget to 0 (previous %d)\n",
-		   XtHeight(old));
-	XtHeight(new_w) = XtHeight(old);
-    }
-#endif
-
     if (_XmGetBGPixmapName() != NULL)
     {
 	XSetWindowAttributes attr;
@@ -964,22 +921,18 @@ set_values(Widget old,
     {
 	need_refresh = True;
     }
-#if XmVERSION > 1
 	if (MGR_Foreground(old) != MGR_Foreground(new_w))
 		msk |= VisualForeground;
-#endif
 
 	if (MGR_HighlightColor(old) != MGR_HighlightColor(new_w)
 			|| MGR_HighlightPixmap(old) != MGR_HighlightPixmap(new_w)) {
 		XtReleaseGC(new_w, MGR_HighlightGC(new_w));
 		CreateHighlightGC(new_w);
 		need_refresh = True;
-#if XmVERSION > 1
 		if (MGR_HighlightColor(old) != MGR_HighlightColor(new_w))
 			msk |= VisualHighlightColor;
 		if (MGR_HighlightPixmap(old) != MGR_HighlightPixmap(new_w))
 			msk |= VisualHighlightPixmap;
-#endif
 	}
 
 	if (MGR_BottomShadowColor(old) != MGR_BottomShadowColor(new_w)
@@ -987,12 +940,10 @@ set_values(Widget old,
 		XtReleaseGC(new_w, MGR_BottomShadowGC(new_w));
 		CreateBottomShadowGC(new_w);
 		need_refresh = True;
-#if XmVERSION > 1
 		if (MGR_BottomShadowColor(old) != MGR_BottomShadowColor(new_w))
 			msk |= VisualBottomShadowColor;
 		if (MGR_BottomShadowPixmap(old) != MGR_BottomShadowPixmap(new_w))
 			msk |= VisualBottomShadowPixmap;
-#endif
 	}
 
 	if (MGR_TopShadowColor(old) != MGR_TopShadowColor(new_w)
@@ -1000,27 +951,22 @@ set_values(Widget old,
 		XtReleaseGC(new_w, MGR_TopShadowGC(new_w));
 		CreateTopShadowGC(new_w);
 		need_refresh = True;
-#if XmVERSION > 1
 		if (MGR_TopShadowColor(old) != MGR_TopShadowColor(new_w))
 			msk |= VisualTopShadowColor;
 		if (MGR_TopShadowPixmap(old) != MGR_TopShadowPixmap(new_w))
 			msk |= VisualTopShadowPixmap;
-#endif
 	}
 
 	if (XtBackground(old) != XtBackground(new_w)) {
 		XtReleaseGC(new_w, MGR_BackgroundGC(new_w));
 		CreateBackgroundGC(new_w);
 		need_refresh = True;
-#if XmVERSION > 1
 		if (XtBackground(old) != XtBackground(new_w))
 			msk |= VisualBackgroundPixel;
-#endif
 	}
 
 	_XmManagerImportArgs(new_w, args, num_args);
 
-#if XmVERSION > 1
 	if (msk) {
 		XmCareVisualTrait	t;
 		int			i;
@@ -1036,60 +982,9 @@ set_values(Widget old,
 			}
 		}
 	}
-#endif
 	return need_refresh;
 }
 
-#if 0
-static XtGeometryResult
-geometry_manager(Widget w,
-		 XtWidgetGeometry *request,
-		 XtWidgetGeometry *reply)
-{
-    /* Motif does not have this method */
-    DEBUGOUT(_LtDebug(__FILE__, w, "geometry_manager()\n"));
-
-    if (reply)
-    {
-	*reply = *request;
-    }
-
-    if (reply->request_mode & CWX)
-    {
-	XtX(w) = reply->x;
-    }
-    if (reply->request_mode & CWY)
-    {
-	XtY(w) = reply->y;
-    }
-    if (reply->request_mode & CWWidth)
-    {
-	XtWidth(w) = reply->width;
-    }
-    if (reply->request_mode & CWHeight)
-    {
-	XtHeight(w) = reply->height;
-    }
-    if (reply->request_mode & CWBorderWidth)
-    {
-	XtBorderWidth(w) = reply->border_width;
-    }
-
-    return XtGeometryYes;
-}
-
-static void
-changed_managed(Widget w)
-{
-    /* Motif does not have this method */
-    /* FIX ME */
-    DEBUGOUT(_LtDebug(__FILE__, w, "ChangeManaged()\n"));
-
-
-    _XmNavigChangeManaged(w);
-}
-#endif
-
 /* constraint class methods */
 
 static void
@@ -2465,8 +2360,6 @@ _XmManagerExportY(Widget widget, int offset, XtArgVal *value)
     *value = converted_value;
 }
 
-
-#if XmVERSION > 1
 static XmDirection 
 get_direction(Widget w)
 {
@@ -2480,7 +2373,6 @@ get_direction(Widget w)
     return MGR_StringDirection(w);
 }
 
-
 extern Widget
 XmObjectAtPoint(Widget w, Position x, Position y)
 {
@@ -2510,4 +2402,3 @@ XmObjectAtPoint(Widget w, Position x, Position y)
     /* Northing found */
     return NULL;
 }
-#endif /* XmVERSION > 1 */
