@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrDefs.c,v 1.2 2001/05/14 19:46:34 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrDefs.c,v 1.3 2004/06/09 18:52:14 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  * Copyright (C) 1997-2001 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrDefs.c,v 1.2 2001/05/14 19:46:34 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrDefs.c,v 1.3 2004/06/09 18:52:14 dannybackx Exp $";
 
 /*
  * This file contains the _XmStrings array for Motif 2.1 libXm
@@ -40,6 +40,9 @@ static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/XmStrD
  * The missing commas are intentional.  Let the compiler
  * concatenate the strings
  */
+#if defined(_MSC_VER) && !defined(STATIC_XM)
+__declspec(dllexport) 
+#endif
 const char _XmStrings[] =
 /* 0     */ "\0"
 /* 1     */ "Accelerator\0"
