@@ -1,4 +1,4 @@
-/* $HEader$
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/togglebg/test2.c,v 1.6 2001/06/18 14:40:11 amai Exp $
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,6 +6,7 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
 
@@ -13,6 +14,7 @@
 #include <Xm/BulletinB.h>
 #include <Xm/ToggleBG.h>
 
+
 int
 main(int argc, char *argv[])
 {
@@ -33,14 +35,14 @@ main(int argc, char *argv[])
 	w = XtCreateWidget("name", xmToggleButtonGadgetClass, bb, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	if ((int)after - (int)before > 0)
+	if ((int)((char *)after - (char *)before) > 0)
 	{
 	    if (iter != 0)
 	    {
 		/*
 		printf("%i %i %p %i\n", iter, iter - diff, after - before, (after - before) / (iter - diff));
 		 */
-		total += (int)after - (int)before;
+		total += (int)((char *)after - (char *)before);
 	    }
 	    diff = iter;
 	}
